cutlass.swizzle - CUTLASS Python

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Source code for cutlass.swizzle

    #################################################################################################
    #
    # Copyright (c) 2023 - 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
    # SPDX-License-Identifier: BSD-3-Clause
    #
    # Redistribution and use in source and binary forms, with or without
    # modification, are permitted provided that the following conditions are met:
    #
    # 1. Redistributions of source code must retain the above copyright notice, this
    # list of conditions and the following disclaimer.
    #
    # 2. Redistributions in binary form must reproduce the above copyright notice,
    # this list of conditions and the following disclaimer in the documentation
    # and/or other materials provided with the distribution.
    #
    # 3. Neither the name of the copyright holder nor the names of its
    # contributors may be used to endorse or promote products derived from
    # this software without specific prior written permission.
    #
    # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
    # AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
    # IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    # DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
    # FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
    # DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
    # SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
    # CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
    # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
    # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    #
    #################################################################################################

    """
    Registry of swizzling functions
    """

    import cutlass_bindings

    IdentitySwizzle1 = cutlass_bindings.IdentitySwizzle1
    IdentitySwizzle2 = cutlass_bindings.IdentitySwizzle2
    IdentitySwizzle4 = cutlass_bindings.IdentitySwizzle4
    IdentitySwizzle8 = cutlass_bindings.IdentitySwizzle8
    HorizontalSwizzle = cutlass_bindings.HorizontalSwizzle
    BatchedIdentitySwizzle = cutlass_bindings.BatchedIdentitySwizzle
    ThreadblockSwizzleStreamK = cutlass_bindings.ThreadblockSwizzleStreamK
    StridedDgradIdentitySwizzle1 = cutlass_bindings.StridedDgradIdentitySwizzle1
    StridedDgradIdentitySwizzle4 = cutlass_bindings.StridedDgradIdentitySwizzle4
    StridedDgradHorizontalSwizzle = cutlass_bindings.StridedDgradHorizontalSwizzle

    _swizzling_functors = [
        IdentitySwizzle1,
        IdentitySwizzle2,
        IdentitySwizzle4,
        IdentitySwizzle8,
        HorizontalSwizzle,
        BatchedIdentitySwizzle,
        ThreadblockSwizzleStreamK,
        StridedDgradIdentitySwizzle1,
        StridedDgradIdentitySwizzle4,
        StridedDgradHorizontalSwizzle,
    ]

    def get_swizzling_functors():
        return _swizzling_functors